===================
django-easy-reports
===================

.. image:: https://secure.travis-ci.org/saxix/django-easy-reports.png?branch=master
   :target: http://travis-ci.org/saxix/django-easy-reports/


.. note:: This project is under heavy development, do not use in production


django-easy-reports is a reports engine for Django applications. The purpose of the project is to provide
a flexible report engine where the end user is free to customize parts of the reports.


Quick Demo Installation
-----------------------

.. code-block:: bash

    make demo


Links
~~~~~

   * Project home page: https://github.com/saxix/django-easy-reports
   * Issue tracker: https://github.com/saxix/django-easy-reports/issues?sort
   * Download: http://pypi.python.org/pypi/django-easy-reports/
   * Docs: http://readthedocs.org/docs/django-easy-reports/en/latest/
